﻿using Electric.Domain.Entities.Commons;
using Electric.Domain.Shared.Entities;
using Electric.Domain.Shared.Entities.Identity;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Permissions;
using System.Text;
using System.Threading.Tasks;

namespace Electric.Domain.Entities.Identity
{
    public class ElePermission : AuditedAggregateRoot<Guid>
    {
        /// <summary>
        /// 权限名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 权限编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// Url地址
        /// </summary>
        public string? Url { get; set; }

        /// <summary>
        /// Vue页面组件
        /// </summary>
        public string? Component { get; set; }

        /// <summary>
        /// 图标
        /// </summary>
        public string? Icon { get; set; }

        /// <summary>
        /// 菜单类型：菜单权限、元素权限、Api权限、数据权限
        /// </summary>
        public PermissionType PermissionType { get; set; }

        /// <summary>
        /// API方法
        /// </summary>
        public string ApiMethod { get; protected set; }

        /// <summary>
        /// 排序
        /// </summary>
        public int Sort { get; set; }

        /// <summary>
        /// 父菜单Id
        /// </summary>
        public long ParentId { get; set; }

        /// <summary>
        /// 状态，0：禁用，1：正常
        /// </summary>
        public PermissionStatus Status { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        public string? Remark { get; set; }

        protected ElePermission()
        {
        }

        public ElePermission(long parentId, Guid id, string name, string url, PermissionType permissionType, PermissionApiMethod apiMethod, PermissionStatus permissionStatus) : base(id)
        {
            ParentId = parentId;
            Name = name;
            Url = url;
            PermissionType = permissionType;
            ApiMethod = apiMethod.ToString();
            Status = permissionStatus;
            Sort = 0;
        }

        /// <summary>
        /// 设置API方法
        /// </summary>
        /// <param name="apiMethod"></param>
        public void SetApiMethod(PermissionApiMethod apiMethod)
        {
            ApiMethod = apiMethod.ToString();
        }
    }
}