﻿using Electric.Domain.Entities.Commons;
using Electric.Domain.Shared.Entities;

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Electric.Domain.Entities.Identity
{
    public class EleRole : AuditedAggregateRoot<Guid>
    {
        /// <summary>
        /// 角色名称
        /// </summary>
        public virtual string? Name { get; set; }

        /// <summary>
        /// 标准化角色名称
        /// </summary>
        public virtual string? NormalizedName { get; set; }

        /// <summary>
        /// 一个随机值，只要角色被持久化到存储中，该值就应该更改
        /// </summary>
        public virtual string? ConcurrencyStamp { get; set; }

        /// <summary>
        /// 状态，0：禁用，1：正常
        /// </summary>
        public RoleStatus Status { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        public string? Remark { get; set; }

        /// <summary>
        /// 声明列表
        /// </summary>
        public ICollection<EleRoleClaim> Claims { get; protected set; }

        /// <summary>
        /// 权限列表
        /// </summary>
        public ICollection<EleRolePermission> Permissions { get; protected set; }

        protected EleRole()
        {
        }

        public EleRole(Guid id, string name) : base(id)
        {
            Name = name;
            NormalizedName = name.ToUpperInvariant();
            ConcurrencyStamp = Guid.NewGuid().ToString("N");
            Status = RoleStatus.Normal;

            Claims = new Collection<EleRoleClaim>();
            Permissions = new Collection<EleRolePermission>();
        }
    }
}